ImageLoader
===========

.. currentmodule:: toasty.image

.. autoclass:: ImageLoader
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageLoader.black_to_transparent
      ~ImageLoader.colorspace_processing
      ~ImageLoader.crop
      ~ImageLoader.psd_single_layer

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageLoader.add_arguments
      ~ImageLoader.create_from_args
      ~ImageLoader.load_path
      ~ImageLoader.load_pil
      ~ImageLoader.load_stream

   .. rubric:: Attributes Documentation

   .. autoattribute:: black_to_transparent
   .. autoattribute:: colorspace_processing
   .. autoattribute:: crop
   .. autoattribute:: psd_single_layer

   .. rubric:: Methods Documentation

   .. automethod:: add_arguments
   .. automethod:: create_from_args
   .. automethod:: load_path
   .. automethod:: load_pil
   .. automethod:: load_stream
